@@ -1,5 +1,5 @@
 /*
- * This file is part of the Nepomuk KDE project.
+ * This file is part of the Baloo KDE project.
  * Copyright (C) 2006-2007 Sebastian Trueg <trueg@kde.org>
  *
  * This library is free software; you can redistribute it and/or
@@ -26,8 +26,8 @@
 #ifndef KBLOCKLAYOUT_H
 #define KBLOCKLAYOUT_H
 
-#include <QtWidgets/QLayout>
-#include <QtWidgets/QLayoutItem>
+#include <QLayout>
+#include <QLayoutItem>
 
 /**
  * The KBlockLayout arranges widget in rows and columns like a text
@@ -37,8 +37,8 @@ class KBlockLayout : public QLayout
 {
  public:
     explicit KBlockLayout( QWidget *parent, int margin = 0, int hSpacing = -1, int vSpacing = -1 );
-    KBlockLayout( int margin = 0, int hSpacing = -1, int vSpacing = -1 );
-    ~KBlockLayout();
+    explicit KBlockLayout( int margin = 0, int hSpacing = -1, int vSpacing = -1 );
+    ~KBlockLayout() override;
 
     /**
      * Set the alignment to use. It can be a combination of a horizontal and
@@ -55,16 +55,16 @@ class KBlockLayout : public QLayout
 
     void setSpacing( int h,  int v );
 
-    void addItem( QLayoutItem* item ) Q_DECL_OVERRIDE;
-    Qt::Orientations expandingDirections() const Q_DECL_OVERRIDE;
-    bool hasHeightForWidth() const Q_DECL_OVERRIDE;
-    int heightForWidth(int) const Q_DECL_OVERRIDE;
-    int count() const Q_DECL_OVERRIDE;
-    QLayoutItem* itemAt( int index ) const Q_DECL_OVERRIDE;
-    QSize minimumSize() const Q_DECL_OVERRIDE;
-    void setGeometry( const QRect& rect ) Q_DECL_OVERRIDE;
-    QSize sizeHint() const Q_DECL_OVERRIDE;
-    QLayoutItem* takeAt( int index ) Q_DECL_OVERRIDE;
+    void addItem( QLayoutItem* item ) override;
+    Qt::Orientations expandingDirections() const override;
+    bool hasHeightForWidth() const override;
+    int heightForWidth(int) const override;
+    int count() const override;
+    QLayoutItem* itemAt( int index ) const override;
+    QSize minimumSize() const override;
+    void setGeometry( const QRect& rect ) override;
+    QSize sizeHint() const override;
+    QLayoutItem* takeAt( int index ) override;
 
  private:
     int doLayout( const QRect& rect, bool testOnly ) const;
