@@ -32,7 +32,6 @@
 #include <QInputDialog>
 
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KLocalizedString>
 
 K_PLUGIN_FACTORY_WITH_JSON(TagsFileItemActionFactory, "tagsfileitemaction.json", registerPlugin<TagsFileItemAction>();)
@@ -46,12 +45,23 @@ TagsFileItemAction::TagsFileItemAction(QObject* parent, const QVariantList&)
 
     connect(&m_tagsLister, &KCoreDirLister::itemsAdded, this, [this](const QUrl&, const KFileItemList& items) {
 
-        for (const KFileItem &item: items) {
-            const QString name = item.name();
+        const QStringList fileTags = m_metaData->tags();
 
+        // The file may be located outside an indexed path, or is not indexed yet
+        // Show the complete tag list, i.e. the union of file and index DB tags
+        QStringList allTags;
+        allTags.reserve(fileTags.size() + items.size());
+        allTags.append(fileTags);
+        for (const KFileItem &item: items) {
+            allTags.append(item.name());
+        }
+        allTags.sort(Qt::CaseInsensitive);
+        allTags.removeDuplicates();
+
+        for (const QString name : qAsConst(allTags)) {
             QAction* action = m_menu->addAction(QIcon::fromTheme(QStringLiteral("tag")), name);
             action->setCheckable(true);
-            action->setChecked(m_metaData->tags().contains(name));
+            action->setChecked(fileTags.contains(name));
 
             connect(action, &QAction::triggered, this, [this, name](bool isChecked) {
                 QStringList newTags = m_metaData->tags();
@@ -89,7 +99,6 @@ TagsFileItemAction::~TagsFileItemAction()
 
 QList<QAction*> TagsFileItemAction::actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget)
 {
-    Q_UNUSED(parentWidget);
 
     if (fileItemInfos.urlList().size() > 1) {
         return {};
@@ -105,7 +114,9 @@ QList<QAction*> TagsFileItemAction::actions(const KFileItemListProperties& fileI
         return {};
     }
 
-    m_tagsLister.openUrl(QUrl("tags:/"), KCoreDirLister::OpenUrlFlag::Reload);
+    m_tagsLister.openUrl(QUrl(QStringLiteral("tags:/")), KCoreDirLister::OpenUrlFlag::Reload);
+
+    m_menu->setParent(parentWidget, Qt::Popup);
 
     return {m_menu->menuAction()};
 }
