@@ -61,7 +61,7 @@ void TagWidgetPrivate::buildTagHash(const QStringList& tags)
     qDeleteAll(m_checkBoxHash);
     m_checkBoxHash.clear();
 
-    foreach (const QString& tag, tags) {
+    for (const QString& tag : tags) {
         getTagCheckBox(tag);
     }
 
@@ -75,7 +75,7 @@ void TagWidgetPrivate::buildTagHash(const QStringList& tags)
     m_showAllLinkLabel = new QLabel( q );
     m_flowLayout->addWidget( m_showAllLinkLabel );
     if (m_readOnly) {
-        m_showAllLinkLabel->setText("-");
+        m_showAllLinkLabel->setText(QStringLiteral("-"));
     }
     else {
         QFont f(q->font());
@@ -181,7 +181,7 @@ void TagWidget::slotKEditTagDialogFinished(int result)
 {
     if( result == QDialog::Accepted ) {
         setSelectedTags( d->m_editTagsDialog->tags() );
-        emit selectionChanged( selectedTags() );
+        Q_EMIT selectionChanged( selectedTags() );
     }
 
     d->m_editTagsDialog->deleteLater();
